#
# spec file for package libxkbfile
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libxkbfile1
Name:           libxkbfile
VCS: https://src.suse.de/SLFO-pool/libxkbfile#7ec10444241981e36513ed4d06bff0bb1ba69d3c231cd124ea991a83b7e745d1
Version:        1.1.2
Release:        160000.2.3
Summary:        X11 keyboard file manipulation library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://xorg.freedesktop.org/
#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libxkbfile
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libxkbfile/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
Patch1237429:   U_CVE-2025-26595-0001-xkb-Fix-buffer-overflow-in-XkbVModMaskText.patch
BuildRequires:  autoconf >= 2.60
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(kbproto)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8

%description
libxkbfile is used by the X servers and utilities to parse the XKB
configuration data files.

%package -n %{lname}
Summary:        X11 keyboard file manipulation library
# O/P added for 12.2
Group:          System/Libraries
Requires:       xkeyboard-config
Provides:       xorg-x11-libxkbfile = 7.6_%{version}-%{release}
Obsoletes:      xorg-x11-libxkbfile < 7.6_%{version}-%{release}

%description -n %{lname}
libxkbfile is used by the X servers and utilities to parse the XKB
configuration data files.

%package devel
Summary:        Development files for the X11 keyboard file manipulation library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
# O/P added for 12.2
Provides:       xorg-x11-libxkbfile-devel = 7.6_%{version}-%{release}
Obsoletes:      xorg-x11-libxkbfile-devel < 7.6_%{version}-%{release}

%description devel
libxkbfile is used by the X servers and utilities to parse the XKB
configuration data files.

This package contains the development headers for the library found
in %{lname}.

%prep
%autosetup -p1

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING
%{_libdir}/libxkbfile.so.1*

%files devel
%{_includedir}/X11/*
%{_libdir}/libxkbfile.so
%{_libdir}/pkgconfig/xkbfile.pc

%changelog
* Sat Feb 22 2025 sndirsch@suse.com
- U_CVE-2025-26595-0001-xkb-Fix-buffer-overflow-in-XkbVModMaskText.patch
  * Buffer overflow in XkbVModMaskText() (CVE-2025-26595, bsc#1237429)
* Thu Dec  8 2022 dmueller@suse.com
- update to 1.1.2:
  * configure: Use AC_SYS_LARGEFILE to enable large file support
- modernize spec file, install license to licensedir
* Tue Oct 18 2022 sndirsch@suse.com
- Update to version 1.1.1
  * Use strndup if available to avoid -Wstringop-overflow warning from gcc 9
  * Convert check for strcasecmp to normal autoconf style
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * fix an off-by-one error in copying the name of a virtual modifier
  * Escape non-printable characters correctly
  * unifdef NOTYET
  * Fix check for appending '|' character when applying rules
* Thu Mar 21 2019 sndirsch@suse.com
- Update to version 1.1.0
  * This release adds support for the NoLock, NoUnlock, and
    genKeyEvent flags.
* Mon Nov  2 2015 eich@suse.com
- add dependency to xkeyboard-config (boo#953161)
* Mon May  4 2015 sndirsch@suse.com
- Update to version 1.0.9
  * This minor maintenance release provides the usual recent
    collection of build configuration improvements and janitorial
    cleanups.
* Mon Apr 14 2014 sndirsch@suse.com
- added missing provides/obsoletes in baselibs.conf (bnc#873443)
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.0.8:
  + Janitorial cleanups
  + Build configuration improvements
* Fri Feb 17 2012 coolo@suse.com
- correct formatting of buildrequires
* Tue Feb 14 2012 sndirsch@suse.com
- added missing provides/obsoletes for xorg-x11-libxkb(-devel)
* Sun Feb 12 2012 jengelh@medozas.de
- Rename xorg-x11-libxkbfile to libxkbfile and utilize shlib policy
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6
* Sat Oct 30 2010 sndirsch@novell.com
- libxkbfile 1.0.7
  * This minor maintenance release provides the usual recent
    collection of build configuration improvements and janitorial
    cleanups.
* Sun Apr  4 2010 sndirsch@suse.de
- libxkbfile 1.0.6
- bumped version number to 7.5
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sat May  2 2009 eich@suse.de
- revert static library and .la file removal
  for SUSE versions <= 11.1.
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Mar 18 2008 sndirsch@suse.de
- libxkbfile 1.0.5
  * bfo #11094: libxkbfile COPYING file
* Wed Jan  2 2008 crrodriguez@suse.de
- fix library-without-ldconfig-* error
- add missing PreReq coreutils
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Sat Oct 14 2006 sndirsch@suse.de
- updated to X.Org 7.2RC1
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
- remove existing /usr/include/X11 symlink in %%pre
* Fri Jun 23 2006 sndirsch@suse.de
- created package
